package de.gematik.smartcard.g2.wrapper;

/**
 * This class provides an exception handling for interface {@link IApduLayer}.
 * <p>
 * <b>History:</b>
 * <ul>
 *   <li>2013-07-18: first edition
 * </ul>
 * 
 * @version 0.1
 * @author <a href="mailto:alfred.fiedler@gematik.de">Alfred Fiedler</a>
 */
public class ApduLayerException extends Exception {
  /** automatic generated number */
  private static final long serialVersionUID = 770749330558211284L;

  /**
   * This class provides a collection of reasons why there is no corresponding response
   * APDU for a command APDU sent via {@link IApduLayer#sendAPDU(byte[])}.
   * <p>
   * <b>History:</b>
   * <ul>
   *   <li>2013-07-18: first edition
   * </ul>
   * 
   * @version 0.1
   * @author <a href="mailto:alfred.fiedler@gematik.de">Alfred Fiedler</a>
   */
  public enum EnumApduLayerException {
    /**
     * The connection to the ICC is broken, e.g. the card was removed from IFD.
     */
    BrokenConnection,
    
    /**
     * This reason is intended for all other error situations. Instead of using
     * this reason a new enum SHALL be added to the list of reasons on request.
     */
    Other;
  } // end EnumApduLayerException
  
  /** contains the reason why the exception is thrown */
  private final EnumApduLayerException m_Reason;
  
  /** additional explanation in case {@link EnumApduLayerException#Other} is used */
  private final String m_Explanation;
  
  /**
   * @param reason causing the exception
   */
  public ApduLayerException(final EnumApduLayerException reason) {
    m_Reason      = reason;
    m_Explanation = "";
  } // end constructor */
  
  /**
   * @param explanation describing why the exception is thrown
   */
  public ApduLayerException(final String explanation) {
    m_Reason      = EnumApduLayerException.Other;
    m_Explanation = explanation;
  } // end constructor */
  
  /* (non-Javadoc)
   * @see java.lang.Throwable#getMessage()
   */
  @Override
  public String getMessage() {
    String result = m_Reason.toString();
    
    if(EnumApduLayerException.Other == m_Reason) {
      result += ", " + m_Explanation;
    } // end if
    
    return result;
  } // end method */
} // end class