package de.gematik.smartcard.g2.wrapper;

/**
 * This interface specifies an ISO/IEC 7816-4 APDU layer.
 * <p>
 * <b>History:</b>
 * <ul>
 *   <li>2013-07-18: {@link ApduLayerException} added
 *   <li>2013-04-10: first edition
 * </ul>
 * 
 * @version 0.2
 * @author <a href="mailto:alfred.fiedler@gematik.de">Alfred Fiedler</a>
 */
public interface IApduLayer {
  /**
   * This function retrieves a response APDU corresponding to the given command APDU
   * by sending the command APDU to a communication channel.
   * <p>
   * This method SHALL either return a response APDU corresponding to ISO/IEC 7816-4
   * or throw an {@link ApduLayerException}.
   * 
   * @param commandAPDU
   *        octet string representation of an ISO/IEC 7816-4 command APDU
   *        
   * @return octet string representation of an ISO/IEC 7816-4 response APDU
   *         corresponding to the given command APDU
   *         
   * @throws ApduLayerException in case a response APDU is not available
   */
  public byte[] sendAPDU(final byte[] commandAPDU) throws ApduLayerException;
} // end interface