package de.gematik.smartcard.g2.wrapper;

import org.w3c.dom.Node;

/**
 * This interface specifies functions to be implemented by a wrapper.
 * <p>
 * <b>History:</b>
 * <ul>
 *   <li>2014-05-21: version 0.2
 *     <ol>
 *       <li>name of method changed
 *       <li>method returns an array rather than a single {@link Node}
 *     </ol>
 *   <li>2014-03-07: first edition
 * </ul>
 * 
 * @version 0.2
 * @author <a href="mailto:alfred.fiedler@gematik.de">Alfred Fiedler</a>
 */
public interface IWrapper {
  /**
   * This function retrieves information about the attributes of an object.
   * <p>
   *  
   * @param apduLayer
   *        used for smart card communication. The caller of this
   *        method shall ensure that the connection is usable.
   *        
   * @param objectLocator
   *        DER encoded octet string with an identifier referencing objects
   *        for which information is requested.
   *   
   * @return {@link Node}[] with information about objects referenced by
   *         objectLocator. The XML structure of each element SHALL be in
   *         accordance to [gemSpec_COS-Wrapper].
   * 
   * @throws ApduLayerException if this exception was thrown when
   *         using the method {@link IApduLayer#sendAPDU(byte[])}
   * 
   * @throws WrapperException in case no proper information could
   *         be provided in the return value.
   */
  public Node[] getInformation(
      final IApduLayer apduLayer,
      final byte[] objectLocator
  ) throws ApduLayerException, WrapperException;
  
  /**
   * This function prepares the device under test such that
   * the command FINGERPRINT could be successfully performed.
   * <p>
   *  
   * @param apduLayer
   *        used for smart card communication. The caller of this
   *        method shall ensure that the connection is usable.
   *        
   * @return true if device under test is prepared for FINGERPRINT command,
   *         false otherwise
   * 
   * @throws ApduLayerException if this exception was thrown when
   *         using the method {@link IApduLayer#sendAPDU(byte[])}
   */
  public boolean prepareFingerprint(
      final IApduLayer apduLayer
  ) throws ApduLayerException;
} // end interface